<?php

/**
 * PHP version 5
 *
 * Copyright © 2014 Daniel Laperdrix
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Plugin test is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugins
 * @package   test
 * 
 * @author    Daniel Laperdrix
 * @copyright 2014 Daniel Laperdrix
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version  
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.78
 */
 
define('GALETTE_BASE_PATH', '../../');
require_once GALETTE_BASE_PATH . 'includes/galette.inc.php';
require_once 'classes/test_pdf.class.php';

if ( !$login->isLogged() ) {
    header("location: index.php");
    die();
}
if ( !$login->isAdmin() && !$login->isStaff() && !$login->isGroupManager() ) {
    header("location: voir_adherent.php");
    die();
}
if ( isset($session['filters']['members']) ) {
    $filters =  unserialize($session['filters']['members']);
} else {
    $filters = new Galette\Filters\MembersList();
}

$members = null;
$m = new Galette\Repository\Members();
$members = $m->getArrayList($filters->selected,array('nom_adh', 'prenom_adh'),true);

if ( !is_array($members) || count($members) < 1 ) {
    die();
}

$doc_title = _T("Member's Labels");
$doc_subject = _T("Generated by Galette");
$doc_keywords = _T("Labels");
// Create new PDF document
$pdf = new Test_pdf();

// Set document information
$pdf->SetTitle($doc_title);
$pdf->SetSubject($doc_subject);
$pdf->SetKeywords($doc_keywords);

// No hearders and footers
$pdf->SetPrintHeader(false);
$pdf->SetPrintFooter(false);
$pdf->setFooterMargin(0);
$pdf->setHeaderMargin(0);

// Show full page
$pdf->SetDisplayMode('fullpage');

// Disable Auto Page breaks
$pdf->SetAutoPageBreak(false, 0);

// Set colors
$pdf->SetDrawColor(160, 160, 160);
$pdf->SetTextColor(0);



// Set origin
// Top left corner

$yorigin=round($_POST['marge_v']/10,1);
$xorigin=round($_POST['marge_h']/10,1);

// Set margins
$pdf->SetMargins($xorigin,$yorigin);
// Label width
$w = round($_POST['taille_h']/10,1);
// Label heigth
$h = round($_POST['taille_v']/10,1);
// Line heigth
$line_h=round($h/7,1);
$nb_etiq=$_POST['no_etiqu'];
if ($nb_etiq >=$_POST['etiq_cols'] * $_POST['etiq_lign']) {
        $nb_etiq =0;
    }
 if ($nb_etiq !=0) {
        $pdf->AddPage();
    }
 
foreach ($members as $member) {
       // Detect page breaks
    if ($nb_etiq % ($_POST['etiq_cols'] * $_POST['etiq_lign']) == 0) {
        $pdf->AddPage();
    }
  
    // Set font
    $pdf->SetFont(Test_pdf::FONT, 'B', $_POST['etiq_corps']);

    // Compute label position
    $col = $nb_etiq % $_POST['etiq_cols'];
    $row = ($nb_etiq / $_POST['etiq_cols']) % $_POST['etiq_lign'];
  
  
    // Set label origin
    $x = $xorigin + $col*($w + round($_POST['esp_h']/10,1));
    $y = $yorigin + $row*($h + round($_POST['esp_v']/10,1));
    
    // Draw a frame around the label
    if ($_POST['encadr'] ) {
	    $pdf->Rect($x, $y, $w, $h);
    }
    // Print full name
    $pdf->SetXY($x, $y);
  
    $ligntext = $pdf->NoDebordText($member->sfullname,$w);  
    $pdf->Cell($w, $line_h, $ligntext[0], 0, 0, 'L', 0);
    // Print first line of adress
    $pdf->SetFont(Test_pdf::FONT, '', $_POST['etiq_corps']);
    $ligntext = $pdf->NoDebordText($member->adress,$w);
    
    if ($ligntext[1]==''){
    $pdf->SetXY($x, $y+$line_h*2);
    $pdf->Cell($w, $line_h,$ligntext[0] , 0, 0, 'L', 0);
    }else {
    $pdf->SetXY($x, $y+$line_h);
    $pdf->Cell($w, $line_h,$ligntext[0] , 0, 0, 'L', 0);	
    $pdf->SetXY($x, $y+$line_h*2);
    $pdf->Cell($w, $line_h, $ligntext[1], 0, 0, 'L', 0);
    }
    // Print second line of adress
    $ligntext = $pdf->NoDebordText($member->adress_continuation,$w);
    $pdf->SetXY($x, $y+$line_h*3);
    $pdf->Cell($w, $line_h, $ligntext[0], 0, 0, 'L', 0);
    $pdf->SetXY($x, $y+$line_h*4);
    $pdf->Cell($w, $line_h, $ligntext[1], 0, 0, 'L', 0);
    // Print zip code and town
    $pdf->SetFont(Test_pdf::FONT, 'B', $_POST['etiq_corps']);
    $ligntext = $pdf->NoDebordText($member->zipcode . ' - ' . $member->town,$w);
    $pdf->SetXY($x, $y+$line_h*5);  
    $pdf->Cell($w, $line_h, $ligntext[0] , 0, 0, 'L', 0);
      // Print country
    $pdf->SetFont(Test_pdf::FONT, 'I', $_POST['etiq_corps']);
    $pdf->SetXY($x, $y+$line_h*6);
    $pdf->Cell($w, $line_h, $member->country, 0, 0, 'R', 0);
    $nb_etiq++;
	
}

// Send PDF code to browser
$pdf->Output('Etiquettes_test.pdf', 'D');
?>